@@ -3,7 +3,6 @@ __docformat__ = 'plaintext'
 
 import logging
 from DateTime import DateTime
-import transaction
 from zope.interface import implements
 
 from Products.CMFCore.utils import getToolByName
@@ -82,40 +81,6 @@ class JobPerformanceInterview(atapi.BaseContent):
                      for item in jobtool.listTemplates()]
             return atapi.DisplayList(items)
 
-    def initializeArchetype(self, **kwargs):
-        """Pre-populate the jobperformance interview.
-
-        Frankly, we would want a separate add form here, instead of an
-        edit form that is also used for adding.
-        """
-        atapi.BaseContent.initializeArchetype(self, **kwargs)
-        # Do not make the text required.
-        self.schema['text'].required = False
-        transaction.savepoint(optimistic=True)
-
-    def setTemplate(self, value):
-        jobtool = getToolByName(self, 'portal_jobperformance', None)
-        if jobtool is None:
-            logger.error("portal_jobperformance cannot be found.")
-            return
-
-        self.template = value
-        pages = [t for t in jobtool.listTemplates()
-                 if t.getId() == value]
-        if not pages:
-            logger.warn("Template %r cannot be found." % value)
-            return
-        template_page = pages[0]
-        # Get the text from the template
-        template_text = template_page.getText()
-        # Substitute parameters
-        view = self.restrictedTraverse('@@substituter')
-        template_text = view.substitute(template_text)
-        self.setText(template_text)
-
-        # Now we can make text required again
-        self.schema['text'].required = True
-
     def template_chosen(self):
         """Determine if the template (a string) has been chosen yet.
         """
